==> 12.6.0.zip: webid-ident-scan-plugin-spm/Package.swift <==
// swift-tools-version:5.3
// The swift-tools-version declares the minimum version of Swift required to build this package.

import PackageDescription

let package = Package(
    name: "WebIdIosIdentScanPlugin",
    platforms: [
        .iOS(.v13)
    ],
    products: [
        // Products define the executables and libraries a package produces, and make them visible to other packages.
        .library(name: "WebIdIosIdentScanPlugin", targets: ["WebIdIosIdentScanPluginWrapper"]),
    ],
    dependencies: [
        // Dependencies declare other packages that this package depends on.
        .package(
            name: "WebIdDocumentScanner",
            url: "https://api.webid-solutions.de/releases/ios/spm/SwiftPackages/webid-document-scanner-spm.git",
            .exact("12.6.0")
        ),
        .package(
            name: "WebIdPluginCore",
            url: "https://api.webid-solutions.de/releases/ios/spm/SwiftPackages/webid-plugin-core-spm.git",
            .exact("12.3.3")
        )
    ],
    targets: [
        .binaryTarget(
            name: "WebIdIosIdentScanPlugin",
            url: "https://api.webid-solutions.de/releases/ios/xcframework/internal/de/webid-solutions/WebIdIosIdentScanPlugin/12.6.0/WebIdIosIdentScanPlugin.framework-v12.6.0.zip",
            checksum: "b118f38c4775c1c194134feb490dbee32e24ee6585e2d83be7346c273306a4b7"
        ),
        .target(
            name: "WebIdIosIdentScanPluginWrapper",
            dependencies: [
                .target(name: "WebIdIosIdentScanPlugin"),
                // [target dependecies here]
                
                .product(name: "WebIdDocumentScanner", package: "WebIdDocumentScanner"),
                .product(name: "WebIdPluginCore", package: "WebIdPluginCore"),
            ]
        )
    ],
    swiftLanguageVersions: [SwiftVersion.v5]
)

==> 13.5.2.zip: webid-ident-scan-plugin-spm/Package.swift <==
// swift-tools-version:5.3
// The swift-tools-version declares the minimum version of Swift required to build this package.

import PackageDescription

let package = Package(
    name: "WebIdIosIdentScanPlugin",
    platforms: [
        .iOS(.v13)
    ],
    products: [
        // Products define the executables and libraries a package produces, and make them visible to other packages.
        .library(name: "WebIdIosIdentScanPlugin", targets: ["WebIdIosIdentScanPluginWrapper"]),
    ],
    dependencies: [
        // Dependencies declare other packages that this package depends on.
        .package(
            name: "WebIdDocumentScanner",
            url: "https://api.webid-solutions.de/releases/ios/spm/SwiftPackageRedesignV4/webid-document-scanner-spm.git",
            .exact("13.5.2")
        ),
        .package(
            name: "WebIdPluginCore",
            url: "https://api.webid-solutions.de/releases/ios/spm/SwiftPackageRedesignV4/webid-plugin-core-spm.git",
            .exact("13.5.2")
        )
    ],
    targets: [
        .binaryTarget(
            name: "WebIdIosIdentScanPlugin",
            url: "https://api.webid-solutions.de/releases/ios/xcframework/redesign-v4/de/webid-solutions/WebIdIosIdentScanPlugin/13.5.2/WebIdIosIdentScanPlugin.framework-v13.5.2.zip",
            checksum: "7340e5932db815a699159e787b10d179716bfa557b82138650f6d9ddd23adffa"
        ),
        .target(
            name: "WebIdIosIdentScanPluginWrapper",
            dependencies: [
                .target(name: "WebIdIosIdentScanPlugin"),
                // [target dependecies here]
                
                .product(name: "WebIdDocumentScanner", package: "WebIdDocumentScanner"),
                .product(name: "WebIdPluginCore", package: "WebIdPluginCore"),
            ]
        )
    ],
    swiftLanguageVersions: [SwiftVersion.v5]
)
